@@ -3,6 +3,7 @@ import ctypes
 import random
 from collections import Counter
 import warnings
+import ctypes
 
 from qlazy.config import *
 from qlazy.error import *
@@ -48,7 +49,7 @@ class Stabilizer(ctypes.Structure):
         ('check_matrix', ctypes.c_void_p),
     ]
 
-    def __new__(cls, qubit_num=None, gene_num=None, pp_list=None, seed=None):
+    def __new__(cls, qubit_num=None, gene_num=None, pp_list=None, seed=None, **kwargs):
         """
         Parameters
         ----------
@@ -63,18 +64,6 @@ class Stabilizer(ctypes.Structure):
         'gene_num' is equal to 'qubit_num.'
 
         """
-        # if qubit_num is None:
-        #     raise Stabilizer_Error_Initialize()
-        # if gene_num is None:
-        #     gene_num = qubit_num
-        # if qubit_num < 1 or gene_num < 1:
-        #     raise Stabilizer_Error_Initialize()
-        # 
-        # if seed is None:
-        #     seed = random.randint(0,1000000)
-        #     
-        # return stabilizer_init(gene_num, qubit_num, seed)
-            
         if seed is None:
             seed = random.randint(0,1000000)
 
@@ -84,7 +73,8 @@ class Stabilizer(ctypes.Structure):
             for pp in pp_list:
                 qubit_num = max([qubit_num] + pp.qid)
             qubit_num += 1
-            sb = stabilizer_init(gene_num, qubit_num, seed)
+            obj = stabilizer_init(gene_num, qubit_num, seed)
+            sb = ctypes.cast(obj.value, ctypes.POINTER(cls)).contents
             for i, pp in enumerate(pp_list):
                 for j, q in enumerate(pp.qid):
                     sb.set_pauli_op(i, q, pp.pauli_list[j])
@@ -97,7 +87,9 @@ class Stabilizer(ctypes.Structure):
                 gene_num = qubit_num
             if qubit_num < 1 or gene_num < 1:
                 raise Stabilizer_Error_Initialize()
-            return stabilizer_init(gene_num, qubit_num, seed)
+            obj = stabilizer_init(gene_num, qubit_num, seed)
+            sb = ctypes.cast(obj.value, ctypes.POINTER(cls)).contents
+            return sb
             
     def __str__(self):
 
@@ -188,13 +180,15 @@ class Stabilizer(ctypes.Structure):
 
         Returns
         -------
-        None
+        self : instance of Stabilizer
+            stabilizer state.
  
         """
         for i in range(self.gene_num):
             for j in range(self.qubit_num):
                 self.set_pauli_op(i,j,'I')
             self.set_pauli_fac(i,'+1')
+        return self
         
     def clone(self):
         """
@@ -210,8 +204,9 @@ class Stabilizer(ctypes.Structure):
             copy of the original stabilizer.
 
         """
-        stab = stabilizer_copy(self)
-        return stab
+        obj = stabilizer_copy(self)
+        sb = ctypes.cast(obj.value, ctypes.POINTER(self.__class__)).contents
+        return sb
 
     def get_rank(self):
 
@@ -527,6 +522,36 @@ class Stabilizer(ctypes.Structure):
 
     # measurement
 
+    def measure(self, qid=None):
+        """
+        one shot measurement in Z-direction.
+
+        Parameters
+        ----------
+        qid : list of int
+            qubit id list to measure.
+
+        Returns
+        -------
+        mval : str
+            measurement value.
+
+        Examples
+        --------
+        >>> sb = Stabilizer(qubit_num=2).set_all('Z').h(0).cx(0,1)
+        >>> sb.show()
+        >>> print(sb.measure(qid=[0,1]))
+        >>> sb.show()
+        g[0]:  XX
+        g[1]:  ZZ
+        00
+        g[0]:  ZI
+        g[1]:  ZZ
+
+        """
+        mval = self.m(qid=qid, shots=1).last
+        return mval
+    
     def m(self, qid=None, shots=DEF_SHOTS):
         """
         measurement in Z-direction.
@@ -545,7 +570,7 @@ class Stabilizer(ctypes.Structure):
 
         Examples
         --------
-        >>> sb = Stabilizer(2).h(0).cx(0,1)
+        >>> sb = Stabilizer(qubit_num=2).set_all('Z').h(0).cx(0,1)
         >>> md = qs.m(qid=[0,1], shots=100)
         >>> print(md.freauency)
         >>> print(md.last)
@@ -623,7 +648,7 @@ class Stabilizer(ctypes.Structure):
 
         Examples
         --------
-        >>> sb = Stabilizer(2).h(0).cx(0,1)
+        >>> sb = Stabilizer(2).set_all('Z').h(0).cx(0,1)
         >>> md = qs.mz(qid=[0,1], shots=100)
         >>> print(md.freauency)
         >>> print(md.last)
@@ -645,7 +670,6 @@ class Stabilizer(ctypes.Structure):
                 mval = stabilizer_measure(st, qid[i])
                 mval_str += str(mval)
             frequency += {mval_str:1}
-            # st.free()
 
         # last measurement
         mval_str = ''
@@ -675,14 +699,6 @@ class Stabilizer(ctypes.Structure):
         None
 
         """
-        # for sb in stabs:
-        #     if type(sb) is list or type(sb) is tuple:
-        #         cls.free_all(*sb)
-        #     elif type(sb) is Stabilizer:
-        #         sb.free()
-        #     else:
-        #         raise Stabilizer_Error_FreeAll()
-
         warnings.warn("No need to call 'free_all' method because free automatically, or you can use class method 'del_all' to free memory explicitly.")
 
     @classmethod
@@ -767,7 +783,6 @@ class Stabilizer(ctypes.Structure):
         None
 
         """
-        # stabilizer_free(self)
         warnings.warn("No need to call 'free' method because free automatically, or you can use 'del' to free memory explicitly.")
 
     def __del__(self):
